@@ -16,6 +16,10 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+/*
+ * $Id: gtk.c,v 1.6 2001/12/30 05:12:04 jason Exp $
+ */
+
 #include <stdlib.h>
 #include <glib.h>
 #include <xmms/util.h>
@@ -35,8 +39,9 @@ static GtkWidget *shn_configurewin = NULL,
 		 *output_error_stderr,
 		 *output_error_window,
 		 *output_error_devnull,
-		 *verbose_frame,
-		 *verbose_vbox,
+		 *misc_frame,
+		 *misc_vbox,
+		 *swap_bytes_toggle,
 		 *verbose_toggle,
 		 *path_frame,
 		 *path_vbox,
@@ -111,6 +116,8 @@ void shn_configurewin_save(void)
 
 	shn_cfg.verbose = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(verbose_toggle));
 
+	shn_cfg.swap_bytes = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(swap_bytes_toggle));
+
 	filename = g_strconcat(g_get_home_dir(), "/.xmms/config", NULL);
 	cfg = xmms_cfg_open_file(filename);
 	if (!cfg)
@@ -119,6 +126,7 @@ void shn_configurewin_save(void)
 	xmms_cfg_write_int(cfg, XMMS_SHN_VERSION_TAG, shn_cfg.error_output_method_config_name, shn_cfg.error_output_method);
 	xmms_cfg_write_boolean(cfg, XMMS_SHN_VERSION_TAG, shn_cfg.verbose_config_name, shn_cfg.verbose);
 	xmms_cfg_write_string(cfg, XMMS_SHN_VERSION_TAG, shn_cfg.seek_tables_path_config_name, shn_cfg.seek_tables_path);
+	xmms_cfg_write_boolean(cfg, XMMS_SHN_VERSION_TAG, shn_cfg.swap_bytes_config_name, shn_cfg.swap_bytes);
 
 	xmms_cfg_write_file(cfg, filename);
 	xmms_cfg_free(cfg);
@@ -200,24 +208,29 @@ void display_shn_configure(void)
 
 /* end error output box */
 
-/* begin verbose box */
+/* begin misc box */
 
-	verbose_frame = gtk_frame_new((gchar *)" Debug options ");
-	gtk_container_set_border_width(GTK_CONTAINER(verbose_frame), 5);
+	misc_frame = gtk_frame_new((gchar *)" Miscellaneous options ");
+	gtk_container_set_border_width(GTK_CONTAINER(misc_frame), 5);
 
-	verbose_vbox = gtk_vbox_new(FALSE, 5);
-	gtk_container_set_border_width(GTK_CONTAINER(verbose_vbox), 5);
-	gtk_container_add(GTK_CONTAINER(verbose_frame), verbose_vbox);
+	misc_vbox = gtk_vbox_new(FALSE, 5);
+	gtk_container_set_border_width(GTK_CONTAINER(misc_vbox), 5);
+	gtk_container_add(GTK_CONTAINER(misc_frame), misc_vbox);
+
+	swap_bytes_toggle = gtk_check_button_new_with_label((gchar *)"Swap audio bytes on output (toggle if all you hear is static)");
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(swap_bytes_toggle), shn_cfg.swap_bytes);
+	gtk_box_pack_start(GTK_BOX(misc_vbox), swap_bytes_toggle, FALSE, FALSE, 0);
+	gtk_widget_show(swap_bytes_toggle);
 
 	verbose_toggle = gtk_check_button_new_with_label((gchar *)"Display debug info to stderr");
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(verbose_toggle), shn_cfg.verbose);
-	gtk_box_pack_start(GTK_BOX(verbose_vbox), verbose_toggle, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(misc_vbox), verbose_toggle, FALSE, FALSE, 0);
 	gtk_widget_show(verbose_toggle);
 
-	gtk_widget_show(verbose_vbox);
-	gtk_widget_show(verbose_frame);
+	gtk_widget_show(misc_vbox);
+	gtk_widget_show(misc_frame);
 
-/* end verbose box */
+/* end misc box */
 
 /* begin seek table path box */
 
@@ -256,7 +269,7 @@ void display_shn_configure(void)
 
 	gtk_box_pack_start(GTK_BOX(options_vbox), output_frame, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(options_vbox), path_frame, FALSE, FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(options_vbox), verbose_frame, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(options_vbox), misc_frame, FALSE, FALSE, 0);
 
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), options_vbox, gtk_label_new((gchar *)"Options"));
 
