@@ -16,6 +16,10 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+/*
+ * $Id: shn.c,v 1.9 2001/12/30 05:12:04 jason Exp $
+ */
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
@@ -85,6 +89,8 @@ static void shn_init()
 	shn_cfg.seek_tables_path_config_name = "seek_tables_path";
 	shn_cfg.verbose = 0;
 	shn_cfg.verbose_config_name = "verbose";
+	shn_cfg.swap_bytes = 0;
+	shn_cfg.swap_bytes_config_name = "swap_bytes";
 
 	filename = g_strconcat(g_get_home_dir(), "/.xmms/config", NULL);
 	if ((cfg = xmms_cfg_open_file(filename)) != 0)
@@ -93,6 +99,7 @@ static void shn_init()
 		xmms_cfg_read_boolean(cfg, XMMS_SHN_VERSION_TAG, shn_cfg.verbose_config_name, &shn_cfg.verbose);
 		if (!xmms_cfg_read_string(cfg, XMMS_SHN_VERSION_TAG, shn_cfg.seek_tables_path_config_name, &shn_cfg.seek_tables_path))
 			shn_cfg.seek_tables_path = g_strdup(g_get_home_dir());
+		xmms_cfg_read_boolean(cfg, XMMS_SHN_VERSION_TAG, shn_cfg.swap_bytes_config_name, &shn_cfg.swap_bytes);
 		xmms_cfg_free(cfg);
 	}
 
@@ -505,9 +512,22 @@ static int is_our_file(char *filename)
 	return TRUE;
 }
 
+void swap_bytes(shn_file *this_shn,int bytes)
+{
+	int i;
+	uchar tmp;
+
+	for (i=0;i<bytes;i=i+2) {
+		tmp = this_shn->vars.buffer[i+1];
+		this_shn->vars.buffer[i+1] = this_shn->vars.buffer[i];
+		this_shn->vars.buffer[i] = tmp;
+	}
+}
+
 void write_and_wait(shn_file *this_shn,int block_size)
 {
-	int bytes_to_write,i;
+	int bytes_to_write,i,x;
+        uchar temp;
 
 	if (this_shn->vars.bytes_in_buf < block_size)
 		return;
@@ -523,9 +543,11 @@ void write_and_wait(shn_file *this_shn,int block_size)
 	while(shn_ip.output->buffer_free() < bytes_to_write && this_shn->vars.going && this_shn->vars.seek_to == -1)
 		xmms_usleep(10000);
 
-	if(this_shn->vars.going && this_shn->vars.seek_to == -1)
+	if(this_shn->vars.going && this_shn->vars.seek_to == -1) {
+		if (shn_cfg.swap_bytes)
+			swap_bytes(this_shn, bytes_to_write);
 		shn_ip.output->write_audio(this_shn->vars.buffer, bytes_to_write);
-	else
+	} else
 		return;
 
 	/* shift data from end of buffer to the front */
